## viskex - interactive visualization for firedrake and FEniCSx ##
<img src="https://viskex.github.io/_images/viskex-logo.png" alt="viskex - interactive visualization for firedrake and FEniCSx" width="150px">

**viskex** is a library for the interactive visualization of finite element simulations within jupyter notebooks in JupyterLab, Google Colab or Kaggle. Supported finite element backends are dolfinx and firedrake.

**viskex** is currently developed and maintained at [Università Cattolica del Sacro Cuore](https://www.unicatt.it/) by [Prof. Francesco Ballarin](https://www.francescoballarin.it).

**viskex** is freely available under the MIT license.

Visit [viskex.github.io](https://viskex.github.io/) for installation instructions and additional information.
